import { BehaviorSubject } from 'rxjs';
import { Api } from './api';
import { TypedEmitter, TypedEvents } from '@ztimson/utils';
import { User } from './users';

export type AuthEvents = TypedEvents & {
    USER: (user: User | null) => any;
    LOGIN: (user: User) => any;
    LOGOUT: () => any;
    REGISTER: (user: Partial<User>) => any;
    RESET_REQUEST: (email: string) => any;
    RESET_COMPLETE: (token: string) => any;
    SESSION_EXPIRED: () => any;
};
export type AuthOptions = {
    loginUi?: string;
    persist?: boolean;
};
export declare class Auth extends TypedEmitter<AuthEvents> {
    private readonly opts?;
    private readonly api;
    private readonly storageKey;
    $user: BehaviorSubject<User | null | undefined>;
    get user(): User | null | undefined;
    set user(user: User | null | undefined);
    constructor(api: Api | string, opts?: AuthOptions | undefined);
    knownHost(host?: string): Promise<void>;
    login(username: string, password: string): Promise<User | null>;
    loginRedirect(host?: string): Promise<string>;
    logout(): void;
    register(user: Partial<User> & {
        username: string;
        password: string;
    }): Promise<void>;
    reset(password: string, token?: string): Promise<void>;
    reset(email: string): Promise<void>;
    whoAmI(token?: string, set?: boolean): Promise<{
        token: string;
        user: User;
        permissions: string[];
    } | null>;
}
//# sourceMappingURL=auth.d.ts.map